@@ -317,7 +317,7 @@ class TableManager:
             `method_name`: reset_test_table
             * @xxx [06-05-2022 16:39:52]: documentation for reset_table
         '''
-        self.test_data_manager.reset_table()
+        return self.test_data_manager.reset_table()
 
     def gen_default_reset(self):
         '''
@@ -370,6 +370,7 @@ class TableManager:
         res = self.generate_test_insert()
         if res:
             return self.reset_test_table()
+        return False
 
     def truncate_table(self):
         '''
