@@ -370,6 +370,9 @@ def remove_keys(data:dict,keys:_Union[list,str],**kwargs)->dict:
         [`reverse`=False] {bool}
             If True, all keys except the ones provided will be removed.
 
+        [`comp_values`=False] {bool}
+            If True, remove keys based on their values
+
         Return {dict}
         ----------------------
         The dict with keys filtered.
@@ -384,21 +387,26 @@ def remove_keys(data:dict,keys:_Union[list,str],**kwargs)->dict:
         * @xxx [06-04-2022 10:23:17]: documentation for remove_keys
     '''
     reverse = get_kwarg(['reverse'], False, (bool), **kwargs)
-    strip_nulls = get_kwarg(['strip_nulls'], False, (bool), **kwargs)
+    comp_values = get_kwarg(['comp_values'], False, (bool), **kwargs)
     keys = _lu.force_list(keys)
 
 
     output = {}
     for k,v in data.items():
-        if strip_nulls is True:
-            if v is None:
-                continue
-        if reverse is True:
-            if k in keys:
-                output[k] = v
+        if comp_values is False:
+            if reverse is True:
+                if k in keys:
+                    output[k] = v
+            else:
+                if k not in keys:
+                    output[k] = v
         else:
-            if k not in keys:
-                output[k] = v
+            if reverse is True:
+                if v in keys:
+                    output[k] = v
+            else:
+                if v not in keys:
+                    output[k] = v
 
     return output
 
